// @ts-nocheck

var licenseFileFullPath = '';
var currentLicenseData;

$(function () {

  /* === Activate JRebel Dialog STARTS === */

  const $activateModal = $("#activate-modal");
  const $activateModalCancel = $("#button-cancel-activate-modal");
  const $activateModalOk = $("#button-ok-activate-modal");
  const $activationDialogInfoMessage = $("#activationdialog-infomessage");
  const $addLicense = $("#button-add-license");
  const $agreeTermsSection = $("#agree-terms-section");
  const $individualTrialTabContent = $("#individual-trial-tab-content");
  const $individualTrialTabTitle = $("#individual-trial-tab-title");
  const $licenseSrc = $('[name="license-src"]');
  const $licensesTitleMessage = $("#licenses-titleMsg");
  const $offlineActivationForm = $("#offline-activation-form");
  const $renewExpiringLicense = $("#button-renew-expiring-license");
  const $trialActivatedForm = $("#trial-activated-form");
  const $trialActivatedMessageContainer = $("#trial-activated-message-container");
  const $trialActivatedMessageGreenLabel = $("#trial-activated-message-greenlabel");
  const $trialActivationCodeText = $("#trial-activation-code-text");

  function showActivationDialogInfoMessage(colorClass, html) {
    $activationDialogInfoMessage.removeClass([ 'displaynone', 'red', 'blue' ])
      .addClass(colorClass)
      .html(html);
  }

  function showLicensesTitleMessage(typeClassName, html) {
    $licensesTitleMessage.removeClass()
      .addClass('section-title-msg')
      .addClass(typeClassName)
      .html(html);
  }

  $addLicense.click(() => {
    $activateModal.css('display', 'block');
  });

  $renewExpiringLicense.click(() => {
    vscode.postMessage({ handlerId: 'licenses', type: 'renewExpiringLicense' });
  });


  const closeModal = function () {
    $activateModal.css('display', 'none');
  };

  const onTabChange = function (titleId) {
    $activateModalOk.prop('disabled', !$('#agree-terms').is(':checked'));
    if (titleId === "commercial-license-tab-title") {
      // commercial license tab has always two buttons
      $agreeTermsSection.removeClass("displaynone");
      $activateModalOk.removeClass("displaynone");
    } else if (titleId === "individual-trial-tab-title") {
      // hide OK button and TOS agreement checkbox only when trial is active or expired
      if (currentLicenseData) {
        if (currentLicenseData.isTrialTabAvailable && (currentLicenseData.trialExpirationText || currentLicenseData.trialActivatedText)) {
          $agreeTermsSection.addClass("displaynone");
          $activateModalOk.addClass("displaynone");
        }
        else if (currentLicenseData.isTrialTabAvailable && currentLicenseData.isOfflineRegistration) {
          $agreeTermsSection.addClass("displaynone");
          $activateModalOk.prop('disabled', !$trialActivationCodeText.val());
        }
      }
    }
  };

  $activateModalCancel.click(handleCancel);

  bindTabAndContent($activateModal, 'commercial-license-tab-title', 'commercial-license-tab-content', 'have-commercial-license', true, onTabChange);
  bindTabAndContent($activateModal, 'individual-trial-tab-title', 'individual-trial-tab-content', 'have-commercial-license', false, onTabChange);

  function radioSelectionChanged() {
    $licenseSrc.each((_, radio) => {
      $('#' + radio.id + '-div').find('input, textarea, button').prop('disabled', !radio.checked);
    });
  }

  $licenseSrc.change(radioSelectionChanged);

  $('#team-url').prop('checked', true); //TODO set according to the business logic
  radioSelectionChanged();

  $('#browse-license-file').click(() => {
    vscode.postMessage({ handlerId: 'licenses', type: 'openFileDialog' });
  });


  $('#agree-terms').click(e => {
    $activateModalOk.prop('disabled', !e.target.checked);
  });

  $trialActivationCodeText.on('input', () => {
    $activateModalOk.prop('disabled', !$trialActivationCodeText.val());
  });

  function scrollToDialogTop() {
    $("#activate-modal .modal-dialog")[0].scroll({ top: 0, behavior: 'smooth' });
  }

  function handleOK() {
    const values = {};
    $activateModal.find('input, textarea').each((_, input) => {
      values[input.id] = input.value;
    });
    $activateModal.find('input[type="checkbox"], input[type="radio"]').each((_, input) => {
      values[input.id] = input.checked;
    });

    values['license-file-input'] = licenseFileFullPath;
    values['offline-activation-form'] = !$offlineActivationForm.hasClass('displaynone');

    showActivationDialogInfoMessage('blue', "Activating...");
    scrollToDialogTop();
    vscode.postMessage({ handlerId: 'licenses', type: 'activateModalOK', values: values });
  }

  $activateModalOk.click(handleOK);

  function handleCancel() {
    resetLicenseDialog();
    if (currentLicenseData) {
      fillLicenseDialog(currentLicenseData);
    }
    closeModal();
  }

  function resetLicenseDialog() {
    $('#license-dialog-data-form')[0].reset();
    $activationDialogInfoMessage.addClass('displaynone');
    $trialActivatedForm.removeClass("displaynone");
    $offlineActivationForm.removeClass("displaynone");
    $trialActivatedMessageContainer.addClass("displaynone");
    $trialActivatedMessageGreenLabel.removeClass("displaynone");
    $individualTrialTabTitle.removeClass("displaynone");
    $individualTrialTabContent.removeClass("displaynone");
    licenseFileFullPath = '';
    $activateModalOk.prop('disabled', true);
  }

  function fillLicenseDialog(data) {
    $('#' + data.tab1SelectedRadio).click();
    let vMap = data.tab1InputValues;
    for (const [key, value] of Object.entries(vMap)) {
        let el = $('#' + key);
        if (key === "license-file-input") {
          el.val(value.filename);
          el.prop('title', value.path);
          el.prop('disabled', false);
          licenseFileFullPath = value.path;
        } else if (el.prop('tagName') === "INPUT") {
          el.val(value);
        } else if (el.prop('tagName') === "TEXTAREA") {
          el.html(value);
        }
    }

    if (data.tab1ExpirationText) {
      showActivationDialogInfoMessage('red', data.tab1ExpirationText);
    }

    if (data.isTrialTabAvailable) {
      if (data.trialExpirationText || data.trialActivatedText) {
        $trialActivatedForm.addClass("displaynone");
        $offlineActivationForm.addClass("displaynone");
        $trialActivatedMessageContainer.removeClass("displaynone");
        // not hiding "agree-terms-section" and "button-ok-activate-modal" here because first tab will be selected by default.

        if (data.trialExpirationText) {
          $trialActivatedMessageGreenLabel.addClass("displaynone");
          $("#trial-activated-message-text").html(data.trialExpirationText);
        } else if (data.trialActivatedText) {
          $trialActivatedMessageGreenLabel.html("JRebel activated.");
          $("#trial-activated-message-text").html(data.trialActivatedText);
        }
      } else {
        // just show the trial activation form as it is.
        $trialActivatedForm.toggleClass("displaynone", data.isOfflineRegistration);
        $offlineActivationForm.toggleClass("displaynone", !data.isOfflineRegistration);
        if (data.isOfflineRegistration) {
          $("#offline-activation-form a").attr("href", data.offlineLink);
        }
      }
    } else {
      console.log("hiding trial tab");
      $individualTrialTabTitle.addClass("displaynone");
      $individualTrialTabContent.addClass("displaynone");
    }
  }

  /* === Activate JRebel Dialog ENDS === */

  $(window).on('message', $e => {
    const event = $e.originalEvent;
    const message = event.data; // The json data that the extension sent
    console.log("licenses.js got event from extension. " + JSON.stringify(message.type));
    switch (message.type) {
      case 'ui.updateLicenseData':
        {
          currentLicenseData = message.data;

          // TODO update elements in a for loop. Iterate over json data element names -> ... -> PROFIT
          if (currentLicenseData.isValidLicense) {
            $("#licenses-licenseType").html(message.data.licenseType);
            $("#licenses-licenseSource").html(message.data.licenseSource);
            $("#licenses-licensedTo").html(message.data.licensedTo);
            $addLicense.html("Change License");
          }

          // prefill activation dialog
          const data = message.data;
          fillLicenseDialog(data);

          if (data.isValidLicense && data.showLicenseExpiringRenewButton !== undefined) {
            if (data.showLicenseExpiringRenewButton) {
              $renewExpiringLicense.removeClass("displaynone");
              $("#licenses-titleMsg").addClass("displaynone"); // hide the "JRebel Activated" message
            } else {
              $renewExpiringLicense.addClass("displaynone");
            }
          }

          if (data.tab1ExpirationText) {
            scrollToDialogTop();
            showLicensesTitleMessage('failure-title-msg', 'JRebel license has expired.');
          }

          if (!data.isValidLicense && !data.tab1ExpirationText) {
            showLicensesTitleMessage('info-title-msg', "Enter a Valid JRebel License");
          }

          break;
        }
      case 'ui.handleActivateLicenseLicensingStatus':
        {
          console.log("licenses.js got handleActivateLicenseLicensingStatus event. data: " + message.data);
          console.dir(message.data);
          if (message.data.isPending) {
            $activationDialogInfoMessage.addClass('displaynone');
            $agreeTermsSection.addClass("displaynone");
            $activateModalOk.addClass("displaynone");

            // trigger Dashboard update as well. TODO JR-11672 doesn't work???
            vscode.postMessage({ handlerId: 'licenses', type: 'licensesLoaded' });

            closeModal(); // close the activationdialog
          }
          else if (message.data.errorMessage) {
            const msgColorClass = message.data.isPending ? 'blue' : 'red';
            showActivationDialogInfoMessage(msgColorClass, message.data.errorMessage);
            scrollToDialogTop();
          } else if (message.data.license && message.data.license.valid) {
            $activationDialogInfoMessage.addClass("displaynone");

            // show "JRebel activated" on panel only once
            showLicensesTitleMessage('success-title-msg', "JRebel Activated");

            // trigger Dashboard update as well. TODO JR-11672 doesn't work???
            vscode.postMessage({ handlerId: 'licenses', type: 'licensesLoaded' });

            closeModal(); // close the activationdialog
          }
          break;
        }
      case 'ui.setLicenseFile':
        {
          const licenseFileInput = $('#license-file-input');
          licenseFileInput.val(event.data.file);
          licenseFileInput.prop('title', event.data.path);
          licenseFileFullPath = event.data.path;
        }
        break;
    }
  });

  console.log("licenses.js loaded");
  vscode.postMessage({ handlerId: 'licenses', type: 'licensesLoaded' });

});
